@@ -102,6 +102,8 @@ from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
                               is_alpha_number,
                               is_nanpa_country,
                               is_number_match,
+                              is_number_geographical,
+                              is_number_type_geographical,
                               is_possible_number,
                               is_possible_number_string,
                               is_possible_number_with_reason,
@@ -135,7 +137,7 @@ from .phonenumbermatcher import PhoneNumberMatch, PhoneNumberMatcher, Leniency
 
 # Version number is taken from the upstream libphonenumber version
 # together with an indication of the version of the Python-specific code.
-__version__ = "7.5.1"
+__version__ = "7.7.4"
 
 __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'REGION_CODE_FOR_NON_GEO_ENTITY', 'NumberFormat', 'PhoneNumberDesc', 'PhoneMetadata',
@@ -164,6 +166,8 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'invalid_example_number',
            'is_alpha_number',
            'is_nanpa_country',
+           'is_number_geographical',
+           'is_number_type_geographical',
            'is_number_match',
            'is_possible_number',
            'is_possible_number_string',
